const dataLoader = require('metalsmith-data-loader');
const pluginKit = require('metalsmith-plugin-kit');

/**
 * Atomic Data Loader
 *
 * Opinionated defaults for the data loader plugin.
 *
 * @param opts
 * @returns {Function}
 */
function atomicDataLoader(opts) {
  const config = pluginKit.defaultOptions(
    {
      dataFolder: '_data',
      dataProperty: 'data',
    },
    opts
  );

  const fn = function(files, metalsmith, done) {
    metalsmith.ignore(`${metalsmith._source}/${config.dataFolder}/**`);
    return dataLoader({
      dataProperty: config.dataProperty,
      directory: `${metalsmith._source}/${config.dataFolder}/`,
      match: '**/*',
      removeSource: true,
    })(files, metalsmith, done);
  };

  pluginKit.renameFunction(fn, 'atomic-data-loader');

  return fn;
}

module.exports = atomicDataLoader;
